You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2009/08/25 13:13:13 UTC

svn commit: r807557 - in /directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers: MatchingRuleDescriptionSchemaParser.java MatchingRuleUseDescriptionSchemaParser.java

Author: elecharny
Date: Tue Aug 25 11:13:13 2009
New Revision: 807557

URL: http://svn.apache.org/viewvc?rev=807557&view=rev
Log:
Foxed the MR and MRU parsers

Modified:
    directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleDescriptionSchemaParser.java
    directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleUseDescriptionSchemaParser.java

Modified: directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleDescriptionSchemaParser.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleDescriptionSchemaParser.java?rev=807557&r1=807556&r2=807557&view=diff
==============================================================================
--- directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleDescriptionSchemaParser.java (original)
+++ directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleDescriptionSchemaParser.java Tue Aug 25 11:13:13 2009
@@ -22,6 +22,7 @@
 
 import java.text.ParseException;
 
+import org.apache.directory.shared.ldap.schema.MatchingRule;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -69,7 +70,7 @@
      * @return the parsed MatchingRuleDescription bean
      * @throws ParseException if there are any recognition errors (bad syntax)
      */
-    public synchronized MatchingRuleDescription parseMatchingRuleDescription( String matchingRuleDescription )
+    public synchronized MatchingRule parseMatchingRuleDescription( String matchingRuleDescription )
         throws ParseException
     {
 
@@ -83,8 +84,8 @@
 
         try
         {
-            MatchingRuleDescription mrd = parser.matchingRuleDescription();
-            return mrd;
+            MatchingRule matchingRule = parser.matchingRuleDescription();
+            return matchingRule;
         }
         catch ( RecognitionException re )
         {
@@ -108,9 +109,9 @@
      * Parses a MatchingRule description
      * 
      * @param The MatchingRule description to parse
      * @return An instance of MatchingRuleDescription
      */
-    public MatchingRuleDescription parse( String schemaDescription ) throws ParseException
+    public MatchingRule parse( String schemaDescription ) throws ParseException
     {
         return parseMatchingRuleDescription( schemaDescription );
     }
@@ -108,9 +109,9 @@
      * 
      * @param The MatchingRule description to parse
-     * @return An instance of MatchingRuleDescription
+     * @return An instance of MatchingRule
      */

Modified: directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleUseDescriptionSchemaParser.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleUseDescriptionSchemaParser.java?rev=807557&r1=807556&r2=807557&view=diff
==============================================================================
--- directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleUseDescriptionSchemaParser.java (original)
+++ directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/parsers/MatchingRuleUseDescriptionSchemaParser.java Tue Aug 25 11:13:13 2009
@@ -22,6 +22,7 @@
 
 import java.text.ParseException;
 
+import org.apache.directory.shared.ldap.schema.MatchingRuleUse;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -70,7 +71,7 @@
      * @return the parsed MatchingRuleUseDescription bean
      * @throws ParseException if there are any recognition errors (bad syntax)
      */
-    public synchronized MatchingRuleUseDescription parseMatchingRuleUseDescription( String matchingRuleUseDescription )
+    public synchronized MatchingRuleUse parseMatchingRuleUseDescription( String matchingRuleUseDescription )
         throws ParseException
     {
 
@@ -84,8 +85,8 @@
 
         try
         {
-            MatchingRuleUseDescription mrud = parser.matchingRuleUseDescription();
-            return mrud;
+            MatchingRuleUse matchingRuleUse = parser.matchingRuleUseDescription();
+            return matchingRuleUse;
         }
         catch ( RecognitionException re )
         {
@@ -110,9 +111,9 @@
      * Parses a MatchingRuleUse description
      * 
      * @param The MatchingRuleUse description to parse
      * @return An instance of MatchingRuleUseDescription
      */
-    public MatchingRuleUseDescription parse( String schemaDescription ) throws ParseException
+    public MatchingRuleUse parse( String schemaDescription ) throws ParseException
     {
         return parseMatchingRuleUseDescription( schemaDescription );
     }
@@ -110,9 +111,9 @@
      * 
      * @param The MatchingRuleUse description to parse
-     * @return An instance of MatchingRuleUseDescription
+     * @return An instance of MatchingRuleUse
      */